
XEP-0446: File metadata element
===============================

.. module:: slixmpp.plugins.xep_0446

.. autoclass:: XEP_0446
    :members:
    :exclude-members: session_bind, plugin_init, plugin_end


Stanza elements
---------------

.. automodule:: slixmpp.plugins.xep_0446.stanza
    :members:
    :undoc-members:

